admin

package
v0.0.0-...-835c9c4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2021 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Callback

func Callback(c buffalo.Context) error

Callback is the auth callback endpoint for administrative log in

func Group

func Group(c buffalo.Context) error

Group shows detailed information about a specific group

func Groups

func Groups(c buffalo.Context) error

Groups is the paginated view of groups

func Impersonate

func Impersonate(c buffalo.Context) error

Impersonate allows an admin to scope themselves as a user

func Login

func Login(c buffalo.Context) error

Login is the administrative page for logging in

func Logout

func Logout(c buffalo.Context) error

Logout is the administrative page for logging out

func Users

func Users(c buffalo.Context) error

Users displays a page of users

Types

This section is empty.

Jump to