sync

package
v0.0.0-...-835c9c4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2021 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Initialize

func Initialize(c buffalo.Context) error

Initialize creates a new Google sheet used for synchronizing data

swagger:route POST /api/v1/admin/sync admin initializeSync Returns a google sheet reference. responses:

  200: adminSyncSheetResponse
	 400: errorResponse
	 401: errorResponse
	 403: errorResponse
	 422: errorResponse
	 500: errorResponse

func Once

func Once(c buffalo.Context) error

Once synchronizes the user and group state to the stored data sheet via a generated slug

swagger:route POST /api/v1/admin/sync/once/{id} admin runSyncOnce Returns a google sheet reference. responses:

  200: adminSyncOnceResponse
	 400: errorResponse
	 401: errorResponse
	 403: errorResponse
	 422: errorResponse
	 500: errorResponse

func Run

func Run(c buffalo.Context) error

Run synchronizes the user and group state to the stored data sheet

swagger:route POST /api/v1/admin/sync/run admin runSync Returns a google sheet reference. responses:

  200: adminSyncSheetResponse
	 400: errorResponse
	 401: errorResponse
	 403: errorResponse
	 422: errorResponse
	 500: errorResponse

Types

type OnceParameters

type OnceParameters struct {
	// in:path
	// required:true
	ID int `json:"id"`
}

OnceParameters documents the inbound parameters used for the Once endpoint swagger:parameters runSyncOnce

type SheetResponse

type SheetResponse struct {
	//in:body
	Body SheetResponsePayload
}

SheetResponse returns a synchronized Google sheet swagger:response adminSyncSheetResponse

type SheetResponsePayload

type SheetResponsePayload struct {
	Sheet string `json:"sheet,omitempty"`
}

SheetResponsePayload contains the synchronized Google sheet

Jump to