common

package
v0.0.0-...-835c9c4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2021 License: MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type TokenPayload

type TokenPayload struct {
	Token string `json:"token"`
}

TokenPayload contain the body parameters for a token exchange

type TokenRequest

type TokenRequest struct {
	// in:body
	// required:true
	Body TokenPayload
}

TokenRequest is a request for a token exchange swagger:parameters exchangeFacebook exchangeGoogle exchangeAdmin

type TokenResponse

type TokenResponse struct {
	// in: body
	Body TokenPayload
}

TokenResponse is a response after a token exchange swagger:response tokenResponse

Jump to