Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Logout ¶
Logout ends the session of the user or scoped admin
swagger:route DELETE /api/v1/logout user logout Log out of the user account. responses:
200: tokenResponse 400: errorResponse 401: errorResponse 403: errorResponse 422: errorResponse 500: errorResponse
Types ¶
type ErrorPayload ¶
type ErrorPayload struct {
Error string `json:"error"`
}
ErrorPayload wraps errors in a well-defined api payload
type ErrorResponse ¶
type ErrorResponse struct {
//in:body
Body ErrorPayload
}
ErrorResponse returns an api error swagger:response apiErrorResponse
type ProfileResponse ¶
type ProfileResponse struct {
//in:body
Body ProfileResponsePayload
}
ProfileResponse returns the user profile information swagger:response profileResponse
type ProfileResponsePayload ¶
type ProfileResponsePayload struct {
User *modelext.UserWithGroup `json:"user"`
}
ProfileResponsePayload contains user profile information
Click to show internal directories.
Click to hide internal directories.