Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TokenPayload ¶
type TokenPayload struct {
Token string `json:"token"`
}
TokenPayload contain the body parameters for a token exchange
type TokenRequest ¶
type TokenRequest struct {
// in:body
// required:true
Body TokenPayload
}
TokenRequest is a request for a token exchange swagger:parameters exchangeFacebook exchangeGoogle exchangeAdmin
type TokenResponse ¶
type TokenResponse struct {
// in: body
Body TokenPayload
}
TokenResponse is a response after a token exchange swagger:response tokenResponse
Click to show internal directories.
Click to hide internal directories.